//Source file: PAMAUEventData.java
//Date: June 2006
//Presence and Availability Management for 3GPP TS 29.198-14 V6.3.0, Release 6

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements to specify the input data for subscribing to agent unassignments from an identity. The event is registered for changes in any of the named agents. If no agents are named, then the event is registered for all assigned agents.
 * 
 */
public final class PAMAUEventData implements java.io.Serializable {

    private String[] identityName;
    private String[] identityType;
    private String[] agentName;
    private String[] agentType;

    /**
     * Creates a new PAMAUEventData instance.
     */
    public PAMAUEventData () {}

    /**
     * Creates a new PAMAUEventData instance.
     * @param _identityName   Specifies the name of the identity for which the unassignment is to be notified. Can be an empty array if notification is required for any identity instance.
     * @param _identityType   Specifies the type of the identity for which this notification is requested if the identityName is specified as an empty array. Can be an empty array if notification required for identities of any type.
     * @param _agentName   Specifies the name of the agent whose unassignment is to be notified. Can be an empty array
     * @param _agentType   Specifies the type of the agent for which this notification is requested if agentName is an empty array. Can be an empty array if notification required for agents of any type
     */
    public PAMAUEventData (String[] _identityName, String[] _identityType, String[] _agentName, String[] _agentType) {

        this.identityName = _identityName;
        this.identityType = _identityType;
        this.agentName = _agentName;
        this.agentType = _agentType;
    }

    /**
     * This method returns a identityName.
     * 
     * @return a String[] value
     */
    public String[] getIdentityName() {
        return identityName;
    }

    /**
     * This method returns a identityType.
     * 
     * @return a String[] value
     */
    public String[] getIdentityType() {
        return identityType;
    }

    /**
     * This method returns a agentName.
     * 
     * @return a String[] value
     */
    public String[] getAgentName() {
        return agentName;
    }

    /**
     * This method returns a agentType.
     * 
     * @return a String[] value
     */
    public String[] getAgentType() {
        return agentType;
    }


    /**
     * This method sets a identityName.
     */ 
    public void setIdentityName(String[] identityName) {
        this.identityName = identityName;
    }

    /**
     * This method sets a identityType.
     */ 
    public void setIdentityType(String[] identityType) {
        this.identityType = identityType;
    }

    /**
     * This method sets a agentName.
     */ 
    public void setAgentName(String[] agentName) {
        this.agentName = agentName;
    }

    /**
     * This method sets a agentType.
     */ 
    public void setAgentType(String[] agentType) {
        this.agentType = agentType;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMAUEventData)) {
            return false;
        } 
        PAMAUEventData pAMAUEventData = (PAMAUEventData) o;
        if(!(this.identityName == pAMAUEventData.identityName))  {
            return false;
        }
        if(!(this.agentName == pAMAUEventData.agentName))  {
            return false;
        }
        if(!(this.agentType == pAMAUEventData.agentType))  {
            return false;
        }
        if(!(this.identityType == pAMAUEventData.identityType))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMAUEventData

