//Source file: PAMAttributeDef.java
//Date: June 2006
//Presence and Availability Management for 3GPP TS 29.198-14 V6.3.0, Release 6

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements containing the definition of an attribute. This definition constitutes the 'schema' for an attribute and contains fields to define the type and behaviour of a dynamic attribute. Each definition using these fields results in a TpPAMAttribute with the corresponding name and type and dynamic behaviour as defined by the remaining fields.
 * 
 */
public final class PAMAttributeDef implements java.io.Serializable {

    private String name;
    private String type;
    private boolean isStatic;
    private boolean isRevertOnExpiration;
    private Object defaultValues;

    /**
     * Creates a new PAMAttributeDef instance.
     */
    public PAMAttributeDef () {}

    /**
     * Creates a new PAMAttributeDef instance.
     * @param _name   Name of presence data
     * @param _type   Type of attribute. Valid values for Type must include at least TpString, TpInt32 and TpFloat.
     * @param _isStatic   True indicates that the attributes is always static and its values never expire. False indicates that the attribute can be dynamic and may contain values that expire.
     * @param _isRevertOnExpiration   True indicates that the attribute reverts to the default value on expiration. False indicates that the attribute will not revert to the default value.
     * @param _defaultValues   An attribute is always initialized with this value. If the isRevertOnExpiration attribute is set to true, a dynamic attribute that has expired while stored in a PAM implementation is reset to this value with the expiresIn interval set to PAM_MAX_LONGINT. The default attribute value is interpreted based on the value of the attribute Type.
     */
    public PAMAttributeDef (String _name, String _type, boolean _isStatic, boolean _isRevertOnExpiration, Object _defaultValues) {

        this.name = _name;
        this.type = _type;
        this.isStatic = _isStatic;
        this.isRevertOnExpiration = _isRevertOnExpiration;
        this.defaultValues = _defaultValues;
    }

    /**
     * This method returns a name.
     * 
     * @return a String value
     */
    public String getName() {
        return name;
    }

    /**
     * This method returns a type.
     * 
     * @return a String value
     */
    public String getType() {
        return type;
    }

    /**
     * This method returns a isStatic.
     * 
     * @return a boolean value
     */
    public boolean getIsStatic() {
        return isStatic;
    }

    /**
     * This method returns a isRevertOnExpiration.
     * 
     * @return a boolean value
     */
    public boolean getIsRevertOnExpiration() {
        return isRevertOnExpiration;
    }

    /**
     * This method returns a defaultValues.
     * 
     * @return a Object value
     */
    public Object getDefaultValues() {
        return defaultValues;
    }


    /**
     * This method sets a name.
     */ 
    public void setName(String name) {
        this.name = name;
    }

    /**
     * This method sets a type.
     */ 
    public void setType(String type) {
        this.type = type;
    }

    /**
     * This method sets a isStatic.
     */ 
    public void setIsStatic(boolean isStatic) {
        this.isStatic = isStatic;
    }

    /**
     * This method sets a isRevertOnExpiration.
     */ 
    public void setIsRevertOnExpiration(boolean isRevertOnExpiration) {
        this.isRevertOnExpiration = isRevertOnExpiration;
    }

    /**
     * This method sets a defaultValues.
     */ 
    public void setDefaultValues(Object defaultValues) {
        this.defaultValues = defaultValues;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMAttributeDef)) {
            return false;
        } 
        PAMAttributeDef pAMAttributeDef = (PAMAttributeDef) o;
        if(!(this.defaultValues == pAMAttributeDef.defaultValues)) {
            return false;
        }
        if ((this.type != null) && (pAMAttributeDef.type != null)) {
            if(!(this.type.equals(pAMAttributeDef.type)))  {
                return false;
            }
        }
        if ((this.name != null) && (pAMAttributeDef.name != null)) {
            if(!(this.name.equals(pAMAttributeDef.name)))  {
                return false;
            }
        }
        if(!(this.isStatic == pAMAttributeDef.isStatic)) {
            return false;
        }
        if(!(this.isRevertOnExpiration == pAMAttributeDef.isRevertOnExpiration)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMAttributeDef

