//Source file: PAMPreferenceType.java
//Date: June 2006
//Presence and Availability Management for 3GPP TS 29.198-14 V6.3.0, Release 6

package org.csapi.jr.se.pam;

/**
 * This specifies the names of privacy and access control mechanisms supported by the service.
 *
 */
public final class PAMPreferenceType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static PAMPreferenceType[] _array = new PAMPreferenceType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PAMPreferenceType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The control data contains additions or modifications to access control list of who is authorized to access the presence information or subscribe to it.
     */
    public static final int _PAM_ACCESS_LIST =  0;

    /**
     * The control data contains additions or modifications to access control list of who is authorized to access the presence information or subscribe to it.
     */
    public static final PAMPreferenceType PAM_ACCESS_LIST = new PAMPreferenceType(_PAM_ACCESS_LIST);

    /**
     * The access control and availability computations are done external to the presence service.
     */
    public static final int _PAM_EXTERNAL_CONTROL =  1;

    /**
     * The access control and availability computations are done external to the presence service.
     */
    public static final PAMPreferenceType PAM_EXTERNAL_CONTROL = new PAMPreferenceType(_PAM_EXTERNAL_CONTROL);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved PAMPreferenceType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PAMPreferenceType object
     */
    public String getValueText() {
        switch (_value) {
            case _PAM_ACCESS_LIST:
                return "PAM_ACCESS_LIST";
            case _PAM_EXTERNAL_CONTROL:
                return "PAM_EXTERNAL_CONTROL";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PAMPreferenceType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMPreferenceType)) {
            return false;
        }
        PAMPreferenceType pAMPreferenceType = (PAMPreferenceType) o; 
        if(!(this.getValue() == pAMPreferenceType.getValue())) {
            return false;
        }
        if (this.hashCode() != pAMPreferenceType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMPreferenceType

