//Source file: PAMPresenceData.java
//Date: June 2006
//Presence and Availability Management for 3GPP TS 29.198-14 V6.3.0, Release 6

package org.csapi.jr.se.pam;

/**
 * This is a Sequence of Data Elements for a presence record. Since multiple presence data records can be associated with an identity, each distinct record is uniquely named.
 * 
 */
public final class PAMPresenceData implements java.io.Serializable {

    private String name;
    private String subscriberStatus;
    private String networkStatus;
    private String communicationMeans;
    private org.csapi.jr.se.Address contactAddress;
    private String subscriberProvidedLocation;
    private String networkProvidedLocation;
    private int priority;
    private String otherInfo;

    /**
     * Creates a new PAMPresenceData instance.
     */
    public PAMPresenceData () {}

    /**
     * Creates a new PAMPresenceData instance.
     * @param _name   Name of presence data
     * @param _subscriberStatus   Specifies the status of the subscriber.
     * @param _networkStatus   Specifies the status of the network.
     * @param _communicationMeans    Specifies the means of communication. The type is TpPAMCapability.
     * @param _contactAddress   Address for communication
     * @param _subscriberProvidedLocation   Location information provided by subscriber. Is optional.
     * @param _networkProvidedLocation   Location information provided by subscriber. Is optional.
     * @param _priority   Priority for communication.
     * @param _otherInfo   Additional information.
     */
    public PAMPresenceData (String _name, String _subscriberStatus, String _networkStatus, String _communicationMeans , org.csapi.jr.se.Address _contactAddress, String _subscriberProvidedLocation, String _networkProvidedLocation, int _priority, String _otherInfo) {

        this.name = _name;
        this.subscriberStatus = _subscriberStatus;
        this.networkStatus = _networkStatus;
        this.communicationMeans = _communicationMeans;
        this.contactAddress = _contactAddress;
        this.subscriberProvidedLocation = _subscriberProvidedLocation;
        this.networkProvidedLocation = _networkProvidedLocation;
        this.priority = _priority;
        this.otherInfo = _otherInfo;
    }

    /**
     * This method returns a name.
     * 
     * @return a String value
     */
    public String getName() {
        return name;
    }

    /**
     * This method returns a subscriberStatus.
     * 
     * @return a String value
     */
    public String getSubscriberStatus() {
        return subscriberStatus;
    }

    /**
     * This method returns a networkStatus.
     * 
     * @return a String value
     */
    public String getNetworkStatus() {
        return networkStatus;
    }

    /**
     * This method returns a communicationMeans.
     * 
     * @return a String value
     */
    public String getCommunicationMeans() {
        return communicationMeans;
    }

    /**
     * This method returns a contactAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getContactAddress() {
        return contactAddress;
    }

    /**
     * This method returns a subscriberProvidedLocation.
     * 
     * @return a String value
     */
    public String getSubscriberProvidedLocation() {
        return subscriberProvidedLocation;
    }

    /**
     * This method returns a networkProvidedLocation.
     * 
     * @return a String value
     */
    public String getNetworkProvidedLocation() {
        return networkProvidedLocation;
    }

    /**
     * This method returns a priority.
     * 
     * @return a int value
     */
    public int getPriority() {
        return priority;
    }

    /**
     * This method returns a otherInfo.
     * 
     * @return a String value
     */
    public String getOtherInfo() {
        return otherInfo;
    }


    /**
     * This method sets a name.
     */ 
    public void setName(String name) {
        this.name = name;
    }

    /**
     * This method sets a subscriberStatus.
     */ 
    public void setSubscriberStatus(String subscriberStatus) {
        this.subscriberStatus = subscriberStatus;
    }

    /**
     * This method sets a networkStatus.
     */ 
    public void setNetworkStatus(String networkStatus) {
        this.networkStatus = networkStatus;
    }

    /**
     * This method sets a communicationMeans.
     */ 
    public void setCommunicationMeans(String communicationMeans) {
        this.communicationMeans = communicationMeans;
    }

    /**
     * This method sets a contactAddress.
     */ 
    public void setContactAddress(org.csapi.jr.se.Address contactAddress) {
        this.contactAddress = contactAddress;
    }

    /**
     * This method sets a subscriberProvidedLocation.
     */ 
    public void setSubscriberProvidedLocation(String subscriberProvidedLocation) {
        this.subscriberProvidedLocation = subscriberProvidedLocation;
    }

    /**
     * This method sets a networkProvidedLocation.
     */ 
    public void setNetworkProvidedLocation(String networkProvidedLocation) {
        this.networkProvidedLocation = networkProvidedLocation;
    }

    /**
     * This method sets a priority.
     */ 
    public void setPriority(int priority) {
        this.priority = priority;
    }

    /**
     * This method sets a otherInfo.
     */ 
    public void setOtherInfo(String otherInfo) {
        this.otherInfo = otherInfo;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PAMPresenceData)) {
            return false;
        } 
        PAMPresenceData pAMPresenceData = (PAMPresenceData) o;
        if ((this.name != null) && (pAMPresenceData.name != null)) {
            if(!(this.name.equals(pAMPresenceData.name)))  {
                return false;
            }
        }
        if ((this.subscriberStatus != null) && (pAMPresenceData.subscriberStatus != null)) {
            if(!(this.subscriberStatus.equals(pAMPresenceData.subscriberStatus)))  {
                return false;
            }
        }
        if ((this.networkStatus != null) && (pAMPresenceData.networkStatus != null)) {
            if(!(this.networkStatus.equals(pAMPresenceData.networkStatus)))  {
                return false;
            }
        }
        if(!(this.communicationMeans == pAMPresenceData.communicationMeans))  {
            return false;
        }
        if ((this.contactAddress != null) && (pAMPresenceData.contactAddress != null)) {
            if(!(this.contactAddress.equals(pAMPresenceData.contactAddress))) {
                return false;
            }
        }
        if ((this.subscriberProvidedLocation != null) && (pAMPresenceData.subscriberProvidedLocation != null)) {
            if(!(this.subscriberProvidedLocation.equals(pAMPresenceData.subscriberProvidedLocation)))  {
                return false;
            }
        }
        if ((this.networkProvidedLocation != null) && (pAMPresenceData.networkProvidedLocation != null)) {
            if(!(this.networkProvidedLocation.equals(pAMPresenceData.networkProvidedLocation)))  {
                return false;
            }
        }
        if(!(this.priority == pAMPresenceData.priority)) {
            return false;
        }
        if ((this.otherInfo != null) && (pAMPresenceData.otherInfo != null)) {
            if(!(this.otherInfo.equals(pAMPresenceData.otherInfo)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PAMPresenceData

