//Source file: PAMEventHandler.java
//Date: June 2006
//Presence and Availability Management for 3GPP TS 29.198-14 V6.3.0, Release 6

package org.csapi.jr.se.pam.event;

/**
 * This interface represents a PAMEventHandler.<BR>
 *
 */
public interface PAMEventHandler extends org.csapi.jr.se.Service {

    /**
     * Adds a PAMEventHandlerListener which is interested in events generated by the PAMEventHandler.
     *
     * @param  pAMEventHandlerListener  A reference to the PAMEventHandlerListener which is to be added as
     *         a listener.
     */
    void addPAMEventHandlerListener(org.csapi.jr.se.pam.event.PAMEventHandlerListener pAMEventHandlerListener);

    /**
     * Removes a PAMEventHandlerListener which is no longer interested in events generated by the PAMEventHandler.
     *
     * @param  pAMEventHandlerListener  A reference to the PAMEventHandlerListener which is to be removed as
     *         a listener.
     */
    void removePAMEventHandlerListener(org.csapi.jr.se.pam.event.PAMEventHandlerListener pAMEventHandlerListener);

    /**
     * Invokes the isRegistered() method on the Parlay Gateway.
     */
    boolean isRegistered(
           byte[]                          authToken)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.pam.PamInvalidCredentialException;

    /**
     * Invokes the deregisterAppInterface() method on the Parlay Gateway.
     */
    void deregisterAppInterface(
           byte[]                          authToken)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.pam.PamNotRegisteredException,
       org.csapi.jr.se.pam.PamInvalidCredentialException;

    /**
     * Invokes the deregisterFromEvent() method on the Parlay Gateway.
     */
    void deregisterFromEvent(
           byte[]                          authToken)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.pam.PamNotRegisteredException,
       org.csapi.jr.se.pam.PamInvalidCredentialException;

    /**
     * Creates a ForEvent object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the ForEvent interface.
     */
    org.csapi.jr.se.pam.event.ForEvent createForEvent();

    /**
     * Creates a AppInterface object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the AppInterface interface.
     */
    org.csapi.jr.se.pam.event.AppInterface createAppInterface();

}
